ReactterInstance<T> class

A singleton instance of T

Constructors

ReactterInstance([String? id, ContextBuilder<T?>? _builder])

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
instance → T?
no setter
key → String
Generating a unique key for a given object T and optional id
no setter
refs ↔ HashSet<int>
Stores the object from which it was instantiated
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stored → ReactterInstance?
A getter that returns the stored instance of T.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

generateKey<T extends Object?>([String? id]) → dynamic
It generates a unique key for a given object T and optional id