ReactterComponent<T extends ReactterContext> class abstract

A abstract StatelessWidget class that provides the functionality of ReactterProvider with a ReactterContext of T, and exposes it through render method.

class App extends ReactterComponent<AppContext> {
  const App({Key? key}) : super(key: key);

  @override
  get builder => () => AppContext();

  @override
  Widget render(AppContext ctx, BuildContext context) {
    return Text("State: ${ctx.stateHook.value}");
  }
}

If you don't use builder getter, the instance of T is not created and is instead tried to be found it in the nearest ancestor where it was created.

Use id getter to create or find a instances of T with an identify:

class App extends ReactterComponent<AppContext> {
  @override
  get id => "uniqueId";
  ...
}

Use listenStates getter to listen states, and when it changed, ReactterComponent's render re-built:

class App extends ReactterComponent<AppContext> {
  @override
  get listenStates => (ctx) => [ctx.stateA, ctx.stateB];
  ...
}

Use listenAll getter as true to listen all states, and when it changed, ReactterComponent's render re-built:

class App extends ReactterComponent<AppContext> {
  @override
  get listenAll => true;
  ...
}

CONSIDER: Dont's use ReactterContext with constructor parameters to prevent conflicts.

See also:

Inheritance

Constructors

ReactterComponent({Key? key})
const

Properties

builder → ContextBuilder<T>?
How to builder the instance of T.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
Id for instance of T.
no setter
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listenAll → bool
Watchs all states to re-build
no setter
listenAllHooks → bool
Watchs all hooks to re-build
no setter
listenHooks → ListenHooks<T>?
Listens hooks to re-build render method.
no setter
listenStates → ListenStates<T>?
Listens states to re-build render method.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(T ctx, BuildContext context) → Widget
Replaces a build method.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited