ReactterContextNotFoundException class

The error that will be thrown if ReactterProvider.contextOf fails to find a ReactterContext as an ancestor of the BuildContext used.

Implemented types

Constructors

ReactterContextNotFoundException(Type valueType, Type widgetType)
Create a ProviderNotFound error with the type represented as a String.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueType → Type
The type of the value being retrieved
final
widgetType → Type
The type of the Widget requesting the value
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited