toString method
A string representation of this object.
Some classes have a default textual representation,
often paired with a static parse function (like int.parse).
These classes will provide the textual representation as
their string representation.
Other classes have no meaningful textual representation
that a program will care about.
Such classes will typically override toString to provide
useful information when inspecting the object,
mainly for debugging or logging.
Implementation
@override
String toString() {
return '''
Error: Could not find the correct `RtScope` above this `$widgetType` Widget
This happens because you used a `BuildContext` without dependency defined:
- You added a new `RtScope` in your `main.dart` and perform a hot-restart.
`RtScope` is a "scoped". So if you insert of `RtScope` inside a route, then
other routes will not be able to access it.
If none of these solutions work, consider asking for help on StackOverflow:
https://stackoverflow.com/questions/tagged/flutter
''';
}